@@ -60,6 +60,7 @@ _fromUtf8 = lambda s: s
 ID_ABOUT  = 101
 ID_EXIT   = 110
 ID_FULLSCREEN  = 111
+ID_GAUGES  = 112
 ID_CONFIG = 500
 ID_CLEAR  = 501
 ID_GETC   = 502
@@ -510,7 +511,8 @@ class MyApp(wx.App):
         self.SpeedWindow1.SetAngleRange(-pi/6, 7*pi/6)
 
         # Create The Intervals That Will Divide Our SpeedMeter In Sectors        
-        intervals = range(0, 201, 20)
+        #intervals = range(0, 201, 20)
+        intervals=self.intervals1
         self.SpeedWindow1.SetIntervals(intervals)
 
         # Assign The Same Colours To All Sectors (We Simulate A Car Control For Speed)
@@ -531,7 +533,8 @@ class MyApp(wx.App):
         self.SpeedWindow1.SetTicksFont(wx.Font(13, wx.SWISS, wx.NORMAL, wx.NORMAL))
                                        
         # Set The Text In The Center Of SpeedMeter
-        self.SpeedWindow1.SetMiddleText("Km/h")
+        self.SpeedWindow1.SetMiddleText(self.SetMiddleText)
+
         # Assign The Colour To The Center Text
         self.SpeedWindow1.SetMiddleTextColour(wx.WHITE)
         # Assign A Font To The Center Text
@@ -650,6 +653,28 @@ class MyApp(wx.App):
 
         self.BToff=BToff
 
+        try:
+           gauges_mph = os.popen('cat /home/opt/pyobd/pyobd.conf | awk \'/gauges/ {print $2}\'').read()
+        except:
+           pass
+
+        lungh = len(str(gauges_mph).strip())
+        if lungh==(4):
+           gauges_mph=True
+        else:
+           gauges_mph=False
+
+        self.gauges_mph=gauges_mph
+        #print self.gauges_mph
+        if self.gauges_mph==True:
+                self.k=0.625
+                self.SetMiddleText="mph"
+                self.intervals1 = range(0, 151, 15)
+        else:
+                self.k=1
+                self.SetMiddleText="Km/h"
+                self.intervals1 = range(0, 201, 20)
+
         #else:
         #  self.COMPORT=self.config.get("pyOBD","COMPORT")
         #  self.RECONNATTEMPTS=self.config.getint("pyOBD","RECONNATTEMPTS")
@@ -705,6 +730,8 @@ class MyApp(wx.App):
         self.filemenu= wx.Menu()
         self.filemenu.Append(ID_FULLSCREEN,"FullScreen ON/OFF","FullScreen")
         self.filemenu.AppendSeparator()
+        self.filemenu.Append(ID_GAUGES,"Configure Gauges","GAUGES")
+        self.filemenu.AppendSeparator()
         self.filemenu.Append(ID_EXIT,"Exit"," Terminate the program")
 
         self.settingmenu = wx.Menu()
@@ -742,7 +769,8 @@ class MyApp(wx.App):
         
         frame.SetMenuBar(self.menuBar)  # Adding the MenuBar to the Frame content.
 
-        frame.Bind(wx.EVT_MENU,self.OnFullScreen,id=ID_FULLSCREEN)         
+        frame.Bind(wx.EVT_MENU,self.On_gauge_mph_kmh,id=ID_GAUGES)
+        frame.Bind(wx.EVT_MENU,self.OnFullScreen,id=ID_FULLSCREEN)
         frame.Bind(wx.EVT_MENU,self.OnExit,id=ID_EXIT) # attach the menu-event ID_EXIT to the   
         frame.Bind(wx.EVT_MENU,self.QueryClear,id=ID_CLEAR)
         frame.Bind(wx.EVT_MENU,self.Configure,id=ID_CONFIG)
@@ -790,7 +818,7 @@ class MyApp(wx.App):
         stringa = 'dbus-send --print-reply --dest=com.nokia.osso_notes /com/nokia/osso_notes com.nokia.osso_notes.mime_open string:/home/opt/pyobd/pyobd.txt'
         os.popen(stringa)
 
-        Text = """ pyobd-0.9.2-18
+        Text = """ pyobd-0.9.2-19
 
 Adapted to n900 by m750 at maemo.org
 """
@@ -861,23 +889,29 @@ later version.
 
 
     def OnDial(self,event):
-
+	#print "k: " + str(self.k)
 	wx.Yield()
 	data=event.data
 	d1=data[:3]
 	d2=int(data[3:])
 	if d1=="kmh":
-		print "speed: "+str(d2)
-		if d2>200:
+		#print "speed: "+str(d2)
+		#print "k: " + str(self.k)
+		#print "speed: "+str(d2*self.k)
+		if d2>200 and self.k==1:
 			d2=200
 			self.SpeedWindow1.SetTicksColour(wx.RED)
+		elif d2>240 and self.k==0.625:
+			d2=240
+			self.SpeedWindow1.SetTicksColour(wx.RED)
+
 		else:
 			self.SpeedWindow1.SetTicksColour(wx.WHITE)
 
-		self.SpeedWindow1.SetSpeedValue(d2)
+		self.SpeedWindow1.SetSpeedValue(d2*self.k)
 
 	elif d1=="rpm":
-		print "rpm: "+str(d2)
+		#print "rpm: "+str(d2)
 		if d2>8000:
 			d2=8000
 			self.SpeedWindow5.SetTicksColour(wx.RED)
@@ -1003,7 +1037,6 @@ later version.
 
 # nome
 
-        #target_name = "CB"
 
            # Loop a couple times in case the device/name isn't found the first time
         while target_address is None and number_of_tries > 0:
@@ -1166,7 +1199,6 @@ later version.
         BT_Static.SetValue(self.BToff)
 
 
-
         
         #web open link button
 #m        self.OpenLinkButton = wx.Button(diag,-1,"Click here to order ELM-USB interface",size=(260,30))
@@ -1190,6 +1222,7 @@ later version.
 
         sizer.Add(BT_Panel,0)
 
+
         box  = wx.BoxSizer(wx.HORIZONTAL)
         box.Add(wx.Button(diag,wx.ID_OK),0)
         box.Add(wx.Button(diag,wx.ID_CANCEL),1)
@@ -1214,7 +1247,14 @@ later version.
                 log2='echo "BToff False" > /home/opt/pyobd/pyobd.conf'
                 os.popen(log2)
 
-            
+              if self.gauges_mph==True:
+                log2='echo "gauges True" >> /home/opt/pyobd/pyobd.conf'
+                os.popen(log2)
+              else:
+                log2='echo "gauges False" >> /home/opt/pyobd/pyobd.conf'
+                os.popen(log2)
+
+           
             #create section
               if self.config.sections()==[]:
                  self.config.add_section("pyOBD")
@@ -1254,7 +1294,46 @@ later version.
 
     def OnFullScreen(self,e = None):
         self.frame.ShowFullScreen(not self.frame.IsFullScreen(), wx.FULLSCREEN_ALL)
-        
+
+    def On_gauge_mph_kmh(self,e = None):
+        id=0
+        diag = wx.Dialog(self.frame, id, title="Configure Gauges")
+        sizer = wx.BoxSizer(wx.VERTICAL)
+
+        mph_Panel = wx.Panel(diag, -1)
+        mph_Static = wx.CheckBox(mph_Panel,-1,' MPH instead KMH in the gauges\n   (To apply the changes, close and reopen pyOBD)',pos=(3,5),size=(700,100))
+        mph_Static.SetValue(self.gauges_mph)
+
+        sizer.Add(mph_Panel,0)
+
+        box  = wx.BoxSizer(wx.HORIZONTAL)
+        box.Add(wx.Button(diag,wx.ID_OK),0)
+        #box.Add(wx.Button(diag,wx.ID_CANCEL),1)
+
+        sizer.Add(box, 0)
+        diag.SetSizer(sizer)
+        diag.SetAutoLayout(True)
+        sizer.Fit(diag)
+        r = diag.ShowModal()
+
+        if r == wx.ID_OK:
+              time.sleep(0.1)
+              self.gauges_mph=mph_Static.GetValue()
+
+              if self.BToff==True:
+                log2='echo "BToff True" > /home/opt/pyobd/pyobd.conf'
+                os.popen(log2)
+              else:
+                log2='echo "BToff False" > /home/opt/pyobd/pyobd.conf'
+                os.popen(log2)
+
+              if self.gauges_mph==True:
+                log2='echo "gauges True" >> /home/opt/pyobd/pyobd.conf'
+                os.popen(log2)
+              else:
+                log2='echo "gauges False" >> /home/opt/pyobd/pyobd.conf'
+                os.popen(log2)
+
         
     def OnExit(self,e = None):
         import sys
